==> fapman_0.4-1.tar.gz: fapman-0.4/aaptinterface.h <==
/*
	This file is part of Faster Application Manager.

	Faster Application Manager is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Faster Application Manager is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Faster Application Manager.  If not, see <http://www.gnu.org/licenses/>.

	(C) Heikki Holstila 2010
*/

#ifndef AAPTINTERFACE_H
#define AAPTINTERFACE_H

#include <QtGui>
#include <QtNetwork>

const QString KLogFileDir = "/root/.fapman";
const QString KLogFileName = "/root/.fapman/lastlog.txt";

class MainWindow;
class FileReadThread;
class DateFetchThread;
class dimmer;
class Package;
class Repository;
class Settings;

class AAptInterface : public QObject
{
	Q_OBJECT

public:
	enum interfaceMode { ModeNone, ModeReadPackages, ModeFetchDates, ModeAptGetUpdate,
						 ModeAptGetSimulate, ModeAptGetInstall, ModeAptGetClean };
	enum multiLine { MultiLineNone, MultiLineDesc, MultiLineIcon };

	AAptInterface(QObject* parent);
	~AAptInterface();
	void setSettings(Settings* s_) { iSettings = s_; }

	void addQueuedOperation(interfaceMode mode_);
	bool run(dimmer* uiDimmer);
	void setProcessPackages(QStringList pkgs) { iProcessPackages=pkgs; iProcessPackagesOrig=pkgs; }
	QStringList processPackages() { return iProcessPackages; }
	QStringList processPackageVersions() { return iProcessPackageVersions; }

	bool running();
	bool cancel();

	int numSelectedPackages() { return iNumSelectedPackages; }
	void setNumSelectedPackages(int p_) { iNumSelectedPackages=p_; }

	QHash<QString, Package*>* packagesAvailable() { return &iPackagesAvailable; }
	QHash<QString, Package*>* packagesInstalled() { return &iPackagesInstalled; }
	QList<Repository*>* repositories() { return  &iRepositories; }

	QByteArray readLogFile();
	void readRepositoryInfo();
	bool writeRepositories();
	bool needRepoRefresh();

private:
	void runNext();
	void cleanAfterRunEach();
	void cleanAfterRunAll();
	void cleanAfterError();

	bool startAptGetUpdate();
	bool startAptGetSimulate();
	bool startAptGetInstall();
	bool startAptGetClean();
	void startThreadFetchDates();

	QString setQProcessErrorMessage(QProcess::ProcessError error);
	QString finishProcessCommonErrorMessages(QByteArray& output);

	void communicateStatusToUi(bool success, QString title="", QString msg="");
	void logToFile( QString data, bool logtime=true );
	void logToFile( QByteArray data, bool logtime=true );

	void startPkgListRead();
	Package* ReadNextPackage(QFile& f);
	bool processPackageDataLine(Package*& pkg, QByteArray& line);

private slots:
	void errorAptGetUpdate(QProcess::ProcessError error);
	void errorAptGetSimulate(QProcess::ProcessError error);
	void errorAptGetInstall(QProcess::ProcessError error);
	void errorAptGetClean(QProcess::ProcessError error);

	void finishedAptGetUpdate(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedAptGetSimulate(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedAptGetInstall(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedAptGetClean(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedThreadDateFetch();

	void uiUpdaterAptGetUpdate();
	void uiUpdaterAptGetInstall();
	void progressCheckTimerCallback();

private:
	QHash<QString, Package*> iPackagesAvailable;
	QHash<QString, Package*> iPackagesInstalled;
	int iNumSelectedPackages;

	QStringList iProcessPackages;
	QStringList iProcessPackagesOrig;
	QStringList iProcessPackageVersions;
	QList<interfaceMode> iOperationsQueue;
	QList<Repository*> iRepositories;
	QStringList iQueueMessages;

	MainWindow* iMainWindow;
	Settings* iSettings;
	interfaceMode iMode;
	QList<interfaceMode> iModeLog;
	dimmer* iUiDimmer;
	bool iCanCancel;
	bool iTerminated;
	bool iErrorDone;
	bool iNeedRepoRefresh;

	QProcess* iProcAptGetUpdate;
	QProcess* iProcAptGetSimulate;
	QProcess* iProcAptGetInstall;
	QProcess* iProcAptGetClean;
	DateFetchThread* iThreadDateFetch;

	int iAptGetDownloadCount;
	int iAptGetInstallCount;
	int iAptGetRemoveCount;
	int iAptGetInstallTotal;
	int iAptGetRemoveTotal;
	int iAptGetCurrentFileDownloadSize;
	int iAptGetCurrentFileTotalSize;
	QString iAptGetCurrentDownloadFileName;
	QTimer* iProgressCheckTimer;

	int iCatalogCounter;

	multiLine iMultiLine;
};



class DateFetchThread : public QThread
{
	Q_OBJECT
public:
	DateFetchThread(QObject* parent);
	void run();

private:

private slots:
	void networkReply(QNetworkReply* reply);
};

#endif // AAPTINTERFACE_H

==> fapman_0.4.1-1.tar.gz: fapman-0.4.1/aaptinterface.h <==
/*
	This file is part of Faster Application Manager.

	Faster Application Manager is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Faster Application Manager is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Faster Application Manager.  If not, see <http://www.gnu.org/licenses/>.

	(C) Heikki Holstila 2010
*/

#ifndef AAPTINTERFACE_H
#define AAPTINTERFACE_H

#include <QtGui>
#include <QtNetwork>

const QString KLogFileDir = "/root/.fapman";
const QString KLogFileName = "/root/.fapman/lastlog.txt";

class MainWindow;
class FileReadThread;
class DateFetchThread;
class dimmer;
class Package;
class Repository;
class Settings;


class AAptInterface : public QObject
{
	Q_OBJECT

public:
	enum interfaceMode { ModeNone, ModeReadPackages, ModeFetchDates, ModeAptGetUpdate,
						 ModeAptGetSimulate, ModeAptGetInstall, ModeAptGetClean };
	enum multiLine { MultiLineNone, MultiLineDesc, MultiLineIcon };

	AAptInterface(QObject* parent);
	~AAptInterface();
	void setSettings(Settings* s_) { iSettings = s_; }

	void addQueuedOperation(interfaceMode mode_);
	bool run(dimmer* uiDimmer);
	void setProcessPackages(QStringList pkgs) { iProcessPackages=pkgs; iProcessPackagesOrig=pkgs; }
	QStringList processPackages() { return iProcessPackages; }
	QStringList processPackageVersions() { return iProcessPackageVersions; }

	bool running();
	bool cancel();

	int numSelectedPackages() { return iNumSelectedPackages; }
	void setNumSelectedPackages(int p_) { iNumSelectedPackages=p_; }

	QHash<QString, Package*>* packagesAvailable() { return &iPackagesAvailable; }
	QHash<QString, Package*>* packagesInstalled() { return &iPackagesInstalled; }
	QList<Repository*>* repositories() { return  &iRepositories; }

	QByteArray readLogFile();
	void readRepositoryInfo();
	bool writeRepositories();
	bool needRepoRefresh();

private:
	void runNext();
	void cleanAfterRunEach();
	void cleanAfterRunAll();
	void cleanAfterError();

	bool startAptGetUpdate();
	bool startAptGetSimulate();
	bool startAptGetInstall();
	bool startAptGetClean();

	QString setQProcessErrorMessage(QProcess::ProcessError error);
	QString finishProcessCommonErrorMessages(QByteArray& output);

	void communicateStatusToUi(bool success, QString title="", QString msg="");
	void logToFile( QString data, bool logtime=true );
	void logToFile( QByteArray data, bool logtime=true );

	void startPkgListRead();
	void startFetchDates();

	Package* ReadNextPackage(QFile& f, quint64& currentreaddata);
	bool processPackageDataLine(Package*& pkg, QByteArray& line);

private slots:
	void errorAptGetUpdate(QProcess::ProcessError error);
	void errorAptGetSimulate(QProcess::ProcessError error);
	void errorAptGetInstall(QProcess::ProcessError error);
	void errorAptGetClean(QProcess::ProcessError error);

	void finishedAptGetUpdate(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedAptGetSimulate(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedAptGetInstall(int exitCode, QProcess::ExitStatus exitStatus);
	void finishedAptGetClean(int exitCode, QProcess::ExitStatus exitStatus);

	void uiUpdaterAptGetUpdate();
	void uiUpdaterAptGetInstall();
	void progressCheckTimerCallback();

private:
	QHash<QString, Package*> iPackagesAvailable;
	QHash<QString, Package*> iPackagesInstalled;
	int iNumSelectedPackages;

	QStringList iProcessPackages;
	QStringList iProcessPackagesOrig;
	QStringList iProcessPackageVersions;
	QList<interfaceMode> iOperationsQueue;
	QList<Repository*> iRepositories;
	QStringList iQueueMessages;

	MainWindow* iMainWindow;
	Settings* iSettings;
	interfaceMode iMode;
	QList<interfaceMode> iModeLog;
	dimmer* iUiDimmer;
	bool iCanCancel;
	bool iTerminated;
	bool iErrorDone;
	bool iNeedRepoRefresh;

	QProcess* iProcAptGetUpdate;
	QProcess* iProcAptGetSimulate;
	QProcess* iProcAptGetInstall;
	QProcess* iProcAptGetClean;
	QByteArray iProcAptGetUpdateOutput;
	QByteArray iProcAptGetInstallOutput;

	int iAptGetDownloadCount;
	int iAptGetInstallCount;
	int iAptGetRemoveCount;
	int iAptGetInstallTotal;
	int iAptGetRemoveTotal;
	int iAptGetCurrentFileDownloadSize;
	int iAptGetCurrentFileTotalSize;
	QString iAptGetCurrentDownloadFileName;
	QTimer* iProgressCheckTimer;

	int iCatalogCounter;
	int iCatalogsTotal;

	multiLine iMultiLine;
};


#endif // AAPTINTERFACE_H
